@@ -25,6 +25,7 @@ use crate::{
     sigverify_shreds::ShredSigVerifier,
     sigverify_stage::SigVerifyStage,
     snapshot_packager_service::PendingSnapshotPackage,
+    voting_service::VotingService,
 };
 use crossbeam_channel::unbounded;
 use solana_ledger::{
@@ -65,6 +66,7 @@ pub struct Tvu {
     ledger_cleanup_service: Option<LedgerCleanupService>,
     accounts_background_service: AccountsBackgroundService,
     accounts_hash_verifier: AccountsHashVerifier,
+    voting_service: VotingService,
 }
 
 pub struct Sockets {
@@ -265,6 +267,10 @@ impl Tvu {
             wait_for_vote_to_start_leader: tvu_config.wait_for_vote_to_start_leader,
         };
 
+        let (voting_sender, voting_receiver) = channel();
+        let voting_service =
+            VotingService::new(voting_receiver, cluster_info.clone(), poh_recorder.clone());
+
         let replay_stage = ReplayStage::new(
             replay_stage_config,
             blockstore.clone(),
@@ -281,6 +287,7 @@ impl Tvu {
             replay_vote_sender,
             gossip_confirmed_slots_receiver,
             gossip_verified_vote_hash_receiver,
+            voting_sender,
         );
 
         let ledger_cleanup_service = tvu_config.max_ledger_shreds.map(|max_ledger_shreds| {
@@ -311,6 +318,7 @@ impl Tvu {
             ledger_cleanup_service,
             accounts_background_service,
             accounts_hash_verifier,
+            voting_service,
         }
     }
 
@@ -324,6 +332,7 @@ impl Tvu {
         self.accounts_background_service.join()?;
         self.replay_stage.join()?;
         self.accounts_hash_verifier.join()?;
+        self.voting_service.join()?;
         Ok(())
     }
 }
